==> sorm_8.2201-2509122314.zip: dyn/ru/bitel/bgbilling/modules/sorm/dyn/upload/CustomUpload.java <==
package ru.bitel.bgbilling.modules.sorm.dyn.upload;

import ru.bitel.bgbilling.kernel.script.server.dev.EventScriptBase;
import ru.bitel.bgbilling.modules.sorm.common.bean.SormProject;
import ru.bitel.bgbilling.modules.sorm.server.event.SormUploadEvent;
import ru.bitel.bgbilling.modules.sorm.server.upload.Upload;
import ru.bitel.bgbilling.server.util.Setup;
import ru.bitel.common.model.Pair;
import ru.bitel.common.sql.ConnectionSet;

import java.nio.file.Path;
import java.util.Collections;
import java.util.List;

public class CustomUpload
    extends EventScriptBase<SormUploadEvent>
{
    @Override
    public void onEvent( SormUploadEvent event, Setup setup, ConnectionSet set )
        throws Exception
    {
        SormProject sormProject = event.getSormProject();
        SormCustomUpload sormCustomUpload = new SormCustomUpload( sormProject, true );
        event.setUploadVersion( sormCustomUpload );
    }

    class SormCustomUpload
        extends Upload
    {
        public SormCustomUpload( SormProject sormProject,
                                 boolean isFullUpload )
        {
            super( sormProject, isFullUpload );
        }

        @Override
        public Path abonents()
        {
            return null;
        }

        @Override
        public Path abonentsAddresses()
        {
            return null;
        }

        @Override
        public Path abonentLogins()
        {
            return null;
        }

        @Override
        public Path services()
        {
            return null;
        }

        @Override
        public Path abonentServices()
        {
            return null;
        }

        @Override
        public Path ipNumbering()
        {
            return null;
        }

        @Override
        public Path abonentsIpNumbering()
        {
            return null;
        }

        @Override
        public Path switches()
        {
            return null;
        }

        @Override
        public Path gateways()
        {
            return null;
        }

        @Override
        public Path bunches()
        {
            return null;
        }

        @Override
        public Path phoneNumbering()
        {
            return null;
        }

        @Override
        public Path phoneNumberingAbonents()
        {
            return null;
        }

        @Override
        public Path documentTypes()
        {
            return null;
        }

        @Override
        public Path paymentTypes()
        {
            return null;
        }

        @Override
        public Path abonentsPayments()
        {
            return null;
        }

        @Override
        public Path operatorInfo()
        {
            return null;
        }

        @Override
        public List<Pair<String, Path>> getOtherFiles()
        {
            return Collections.emptyList();
        }
    }
}

==> sorm_9.2310-2408301819.zip: dyn/ru/bitel/bgbilling/modules/sorm/dyn/upload/CustomUpload.java <==
package ru.bitel.bgbilling.modules.sorm.dyn.upload;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import ru.bitel.bgbilling.kernel.script.server.dev.EventScriptBase;
import ru.bitel.bgbilling.modules.sorm.common.bean.SormProject;
import ru.bitel.bgbilling.modules.sorm.server.event.SormUploadEvent;
import ru.bitel.bgbilling.modules.sorm.server.upload.Upload;
import ru.bitel.bgbilling.server.util.Setup;
import ru.bitel.common.model.Pair;
import ru.bitel.common.sql.ConnectionSet;

import java.nio.file.Path;
import java.util.Collections;
import java.util.List;

public class CustomUpload
    extends EventScriptBase<SormUploadEvent>
{
    private static final Logger logger = LogManager.getLogger();

    @Override
    public void onEvent( SormUploadEvent event, Setup setup, ConnectionSet set )
        throws Exception
    {
        SormProject sormProject = event.getSormProject();
        SormCustomUpload sormCustomUpload = new SormCustomUpload( sormProject, true );
        event.setUploadVersion( sormCustomUpload );
    }

    class SormCustomUpload
        extends Upload
    {
        public SormCustomUpload( SormProject sormProject,
                                 boolean isFullUpload )
        {
            super( sormProject, isFullUpload );
        }

        @Override
        public Path abonents()
        {
            return null;
        }

        @Override
        public Path abonentsAddresses()
        {
            return null;
        }

        @Override
        public Path abonentLogins()
        {
            return null;
        }

        @Override
        public Path services()
        {
            return null;
        }

        @Override
        public Path abonentServices()
        {
            return null;
        }

        @Override
        public Path ipNumbering()
        {
            return null;
        }

        @Override
        public Path abonentsIpNumbering()
        {
            return null;
        }

        @Override
        public Path switches()
        {
            return null;
        }

        @Override
        public Path gateways()
        {
            return null;
        }

        @Override
        public Path bunches()
        {
            return null;
        }

        @Override
        public Path phoneNumbering()
        {
            return null;
        }

        @Override
        public Path phoneNumberingAbonents()
        {
            return null;
        }

        @Override
        public Path documentTypes()
        {
            return null;
        }

        @Override
        public Path paymentTypes()
        {
            return null;
        }

        @Override
        public Path abonentsPayments()
        {
            return null;
        }

        @Override
        public Path operatorInfo()
        {
            return null;
        }

        @Override
        public List<Pair<String, Path>> getOtherFiles()
        {
            return Collections.emptyList();
        }
    }
}
